//HANDLES THE LOGIC FOR THE PLAYBACK DURATION (I.E. XX:XX / YY:YY)


//Perhaps this should be done in the playbackService.js file of the add-on so that we don't have to repeat this code

define(["servicesFactory", 
	'NB'], 
	function(servicesFactory, NB){

	servicesFactory.factory('PlaybackTimerService', 
		['$interval', 
		function($interval){

		var playbackTimer = {
			liveMinutes: "00",
			liveSeconds: '00',
			liveColon: ':',
			liveDivider: '/',
			liveIteration: null,
			totalRecordedTime: 0,
			time: 0,
			startTime: 0,
			currentTime: 0,
			pauseTime: 0,
			startPauseTime: 0,
			endPauseTime: 0,

			//Starts the playbackTimerService counter and will determine the total recorded time (so that it knows when to stop increasing the counter)
			//Can also work as resume()
			start: function(recordedTime){ 
				playbackTimer.resetCounters();
				playbackTimer.startTime = new Date();
				playbackTimer.totalRecordedTime = recordedTime;
				playbackTimer.liveIteration = $interval(playbackTimer.incCounter, 1000);
			},	

			//Writes the time values onto the HTML 
			updateLiveView: function(){
				playbackTimer.liveMinutes = Math.floor(playbackTimer.time/60);
				playbackTimer.liveSeconds = Math.floor(playbackTimer.time%60);
				playbackTimer.liveColon = ':';
				playbackTimer.liveDivider = "/";

				//Time formatting
				if (playbackTimer.liveMinutes<10){
					playbackTimer.liveMinutes = "0"+playbackTimer.liveMinutes;
				}

				if (playbackTimer.liveSeconds<10){
					playbackTimer.liveSeconds = "0" +playbackTimer.liveSeconds;
				}

				//Time formatting
				if (playbackTimer.decMinutes<10){
					playbackTimer.decMinutes = "0"+playbackTimer.decMinutes;
				}

				if (playbackTimer.decSeconds<10){
					playbackTimer.decSeconds = "0" +playbackTimer.decSeconds;
				}
			},

			//Pauses the playbackTimerService counter from increasing
			pause: function(){ 
				playbackTimer.startPauseTime = new Date();
				$interval.cancel(playbackTimer.liveIteration);
			},

			//Stops the playbackTimerService counter from increasing
			//Resets the counter to 0 and updates the duration values on the HTML
			//Also works as playbackTimerService.stop() 
			prev: function(){ 
				$interval.cancel(playbackTimer.liveIteration);
				playbackTimer.resetCounters();
				playbackTimer.updateLiveView();
			},

			//Skips to the end of the recorded duration and stops increasing the playbackTimerService counter
			next: function(totalDuration){
				if (totalDuration === undefined){
					playbackTimer.time = playbackTimer.totalRecordedTime;
				}
				else{
					playbackTimer.time = totalDuration;
				}
				
				playbackTimer.pauseTime = 0;
				playbackTimer.startPauseTime = 0;
				playbackTimer.endPauseTime = 0;
				playbackTimer.updateLiveView();
				$interval.cancel(playbackTimer.liveIteration);
			},	

			resume: function(){
				playbackTimer.endPauseTime = new Date();
				playbackTimer.pauseTime = ((playbackTimer.endPauseTime - playbackTimer.startPauseTime)/1000) + playbackTimer.pauseTime;
				playbackTimer.liveIteration = $interval(playbackTimer.incCounter, 1000);
			},

			//Clears the playback duration values on the HTML
			clearTimer: function(){
				playbackTimer.liveMinutes = "00";
				playbackTimer.liveSeconds = "00";
				playbackTimer.liveColon = ":";
				playbackTimer.liveDivider = "/";
			},

			//Increases the playbackTimerService counter every second and updates the values onto the HTML
			incCounter: function(){
				playbackTimer.currentTime = new Date();
				playbackTimer.time = ((playbackTimer.currentTime - playbackTimer.startTime)/1000) - playbackTimer.pauseTime;

				//When the counter hits the total duration, stop increasing the counter (or stop playing)
				if (playbackTimer.time >= playbackTimer.totalRecordedTime){
					playbackTimer.time = playbackTimer.totalRecordedTime; 
					$interval.cancel(playbackTimer.liveIteration);
				}
				
				playbackTimer.updateLiveView(); 
			},

			resetCounters: function(){
				playbackTimer.time = 0;
				playbackTimer.startTime = 0;
				playbackTimer.currentTime = 0;
				playbackTimer.pauseTime = 0;
				playbackTimer.startPauseTime = 0;
				playbackTimer.endPauseTime = 0;
			}
		};

		return playbackTimer;
	}]);
});