//HANDLES THE LOGIC FOR THE RECORDING DURATION (I.E. DURATION DISPLAYED IN THE RECORDING BUTTON)


define(["servicesFactory", "NB"], function(servicesFactory, NB){

	servicesFactory.factory('RecordingTimerService', ['$interval', function($interval){

		var _scope;
		var widgetAnnotation = NB.getHostObject(); //Retrieve the host object (or the widget annotation itself) so that we can save and load properties from it 

		var recordingTimer = {
			minutesElapsed: "00",
			secondsElapsed: "00",
			liveIteration: null,
			blinkIteration: null,
			colon: ":",
			minutesRecorded: "00",
			secondsRecorded: "00",
			colonRecorded: ":",
			isBlinking: false,
			time: 0,
			startTime: 0,
			currentTime: 0,

			//Starts the iteration of the recordingTimer counter 
			start: function(){
				recordingTimer.startTime = new Date();
				recordingTimer.liveIteration = $interval(recordingTimer.incCounter, 1000);
			},

			//Writes the time values onto the HTML 
			updateRecordingView: function(){
				recordingTimer.minutesElapsed = Math.floor(recordingTimer.time/60);
				recordingTimer.secondsElapsed = Math.floor(recordingTimer.time%60);
				recordingTimer.colon = ":";

				//Time formatting
				if (recordingTimer.minutesElapsed<10){
					recordingTimer.minutesElapsed = "0"+recordingTimer.minutesElapsed;
				}

				if (recordingTimer.secondsElapsed<10){
					recordingTimer.secondsElapsed = "0" +recordingTimer.secondsElapsed;
				}
			},

			//Once the recording has finished, the recorded duration will be written to another section on the HTML (total duration)
			setTotalDuration: function(recordedTime){
				recordingTimer.minutesRecorded = Math.floor(recordedTime/60);
				recordingTimer.secondsRecorded = Math.floor(recordedTime%60);
				recordingTimer.colonRecorded = recordingTimer.colon;

				if (recordingTimer.minutesRecorded<10){
					recordingTimer.minutesRecorded = "0"+recordingTimer.minutesRecorded;
				}

				if (recordingTimer.secondsRecorded<10){
					recordingTimer.secondsRecorded = "0" +recordingTimer.secondsRecorded;
				}
			},

			//Loads the total recorded duration from the widget annotation
			loadTotalDuration: function(minutes, seconds){
				recordingTimer.minutesRecorded = minutes;
				recordingTimer.secondsRecorded = seconds;
			},

			//Clears the live recording duration on the HTML
			clearLiveRecordingDuration: function(){
				recordingTimer.minutesElapsed = "00";
				recordingTimer.secondsElapsed = "00";
				recordingTimer.colon = ":";
			},

			//Clears the total recorded duration on the HTML
			clearTotalDuration: function(){
				recordingTimer.minutesRecorded = "00";
				recordingTimer.secondsRecorded = "00";
				recordingTimer.colonRecorded = ":";
			},

			//Clears both the live recording and the total recorded duration on the HTML
			clearTimer: function(){
				recordingTimer.clearTotalDuration();
				recordingTimer.clearLiveRecordingDuration();
			},

			//Stops the live recording session and writes the total recorded duration on the HTML
			//Live recorded duration is cleared
			//recordingTimer will stop iterating
			stop: function(recordedTime){ 
				recordingTimer.setTotalDuration(recordedTime); 
				recordingTimer.clearLiveRecordingDuration();
				$interval.cancel(recordingTimer.liveIteration);
			},

			//Increases the recordingTimer counter every second and updates the duration values on the HTML
			incCounter: function(){
				recordingTimer.currentTime = new Date();
				recordingTimer.time = (recordingTimer.currentTime - recordingTimer.startTime)/1000;
				recordingTimer.updateRecordingView(); 
			},

			blink: function(){
				recordingTimer.blinkIteration = $interval(recordingTimer.blinkToggle, 500);
			},

			blinkToggle: function(){
				recordingTimer.isBlinking = !recordingTimer.isBlinking;
			},

			stopBlink: function(){
				recordingTimer.isBlinking = false;
				$interval.cancel(recordingTimer.blinkIteration);
			}
		};

		recordingTimer.init = function(scope){
			_scope = scope;
			return recordingTimer;
		};

		return recordingTimer;
	}]);
});