//EVENTS THAT THE WIDGET FIRES TO THE ADD-ON
//When a button is clicked on the widget playback controls, an corresponding event will be fired and then received by the add-on
//where the appropriate action will then take place - Justin

define(["servicesFactory", 
	"NB", 
	"services/recordingTimerService",
	"services/playbackTimerService"], 

	function(servicesFactory, 
		NB){

	servicesFactory.factory('WidgetReceiveEventService', 
		["RecordingTimerService", 
		"PlaybackTimerService",
		function(recordingTimerService,
			playbackTimerService){

		var _scope;

		//Object that the widgetReceiveEventService.js file returns
		//This object holds dummy links to the view (e.g. playback controls, timers, etc.) 
		var widgetReceiveEventService = {
            playButton: 'disabled',
            pauseButton: 'hidden',
            prevButton: 'disabled',
            nextButton: 'disabled',
            recordingButton: 'enabled',
            stopRecordingButton: 'hidden',
            loopState: false,
            loopButton: 'disabled',
            playbackTime: 'hidden',
            recordingDuration: 'hidden'
		};

		//Since we're updating variables outside of Angular's knowledge, we'll have to $digest() everytime an update has been made 
		//so that the changes are reflected in the view
		widgetReceiveEventService.init = function(scope){
			_scope = scope;

			return widgetReceiveEventService;
		};

		/*------------------------------------------ OBSERVERS TO LISTEN TO EVENTS FIRED BACK FROM THE ADD-ON TO UPDATE WIDGET UI ---------------------------------*/

		NB.addObserver('recordFeedback', function(evt){
			widgetReceiveEventService.recordingButton = 'hidden';
			widgetReceiveEventService.stopRecordingButton = 'active';
			widgetReceiveEventService.playButton = 'disabled';
			widgetReceiveEventService.pauseButton = 'hidden';
			widgetReceiveEventService.prevButton = 'disabled';
			widgetReceiveEventService.nextButton = 'disabled';
			widgetReceiveEventService.loopButton = 'disabled';
			widgetReceiveEventService.playbackTime = 'hidden';
			widgetReceiveEventService.recordingDuration = 'active';
			_scope.$digest();
		});

		NB.addObserver('stopRecordingFeedback', function(evt){
			widgetReceiveEventService.recordingButton = 'active';
			widgetReceiveEventService.stopRecordingButton = 'hidden';
			widgetReceiveEventService.playButton = 'enabled';
			widgetReceiveEventService.pauseButton = 'hidden';
			widgetReceiveEventService.prevButton = 'disabled';
			widgetReceiveEventService.nextButton = 'disabled';
			widgetReceiveEventService.loopButton = 'enabled';
			widgetReceiveEventService.playbackTime = 'active';
			widgetReceiveEventService.recordingDuration = 'hidden';
			_scope.$digest();
		});

		NB.addObserver('stopRecordingButNoRecordingFeedback', function(evt){
			widgetReceiveEventService.recordingButton = 'active';
			widgetReceiveEventService.stopRecordingButton = 'hidden';
			widgetReceiveEventService.playButton = 'disabled';
			widgetReceiveEventService.pauseButton = 'hidden';
			widgetReceiveEventService.prevButton = 'disabled';
			widgetReceiveEventService.nextButton = 'disabled';
			widgetReceiveEventService.loopButton = 'disabled';
			widgetReceiveEventService.playbackTime = 'hidden';
			widgetReceiveEventService.recordingDuration = 'hidden';
			_scope.$digest();
		});

		NB.addObserver('skipToBeginningFeedback', function(evt){
			widgetReceiveEventService.recordingButton = 'enabled';
			widgetReceiveEventService.stopRecordingButton = 'hidden';
			widgetReceiveEventService.playButton = 'enabled';
			widgetReceiveEventService.pauseButton = 'hidden';
			widgetReceiveEventService.prevButton = 'disabled';
			widgetReceiveEventService.nextButton = 'enabled';
			widgetReceiveEventService.loopButton = 'enabled';
			widgetReceiveEventService.playbackTime = 'active';
			widgetReceiveEventService.recordingDuration = 'hidden';
			_scope.$digest();
		});

		NB.addObserver('skipToEndFeedback', function(evt){
			widgetReceiveEventService.recordingButton = 'enabled';
			widgetReceiveEventService.stopRecordingButton = 'hidden';
			widgetReceiveEventService.playButton = 'enabled';
			widgetReceiveEventService.pauseButton = 'hidden';
			widgetReceiveEventService.prevButton = 'enabled';
			widgetReceiveEventService.nextButton = 'disabled';
			widgetReceiveEventService.loopButton = 'enabled';
			widgetReceiveEventService.playbackTime = 'active';
			widgetReceiveEventService.recordingDuration = 'hidden';
			_scope.$digest();
		});

		NB.addObserver('playFeedback', function(evt){
			widgetReceiveEventService.recordingButton = 'disabled';
			widgetReceiveEventService.stopRecordingButton = 'hidden';
			widgetReceiveEventService.playButton = 'hidden';
			widgetReceiveEventService.pauseButton = 'active';
			widgetReceiveEventService.prevButton = 'enabled';
			widgetReceiveEventService.nextButton = 'enabled';
			widgetReceiveEventService.loopButton = 'enabled';
			widgetReceiveEventService.playbackTime = 'active';
			widgetReceiveEventService.recordingDuration = 'hidden';
			_scope.$digest();
		});

		NB.addObserver('pauseFeedback', function(evt){
			widgetReceiveEventService.recordingButton = 'disabled';
			widgetReceiveEventService.stopRecordingButton = 'hidden';
			widgetReceiveEventService.playButton = 'active';
			widgetReceiveEventService.pauseButton = 'hidden';
			widgetReceiveEventService.prevButton = 'enabled';
			widgetReceiveEventService.nextButton = 'enabled';
			widgetReceiveEventService.loopButton = 'enabled';
			widgetReceiveEventService.playbackTime = 'active';
			widgetReceiveEventService.recordingDuration = 'hidden';
			_scope.$digest();
		});

		NB.addObserver('newRecordingFeedback', function(evt){
			widgetReceiveEventService.recordingButton = 'enabled';
			widgetReceiveEventService.stopRecordingButton = 'hidden';
			widgetReceiveEventService.playButton = 'disabled';
			widgetReceiveEventService.pauseButton = 'hidden';
			widgetReceiveEventService.prevButton = 'disabled';
			widgetReceiveEventService.nextButton = 'disabled';
			widgetReceiveEventService.loopButton = 'disabled';
			widgetReceiveEventService.playbackTime = 'hidden';
			widgetReceiveEventService.recordingDuration = 'hidden';
			_scope.$digest();
		});

		NB.addObserver("updateWidgetTimeStamp", function(evt){
			var totalDuration = evt.eventData.minutesRecorded*60 + evt.eventData.secondsRecorded;
			recordingTimerService.loadTotalDuration(evt.eventData.minutesRecorded, evt.eventData.secondsRecorded);
			playbackTimerService.next(totalDuration);
			_scope.$digest();
		});
		
		NB.addObserver('startBlinkFeedback', function(evt){
			recordingTimerService.blink();
		});

		NB.addObserver('stopBlinkFeedback', function(evt){
			recordingTimerService.stopBlink();
		});

		NB.addObserver('startStopWatchFeedback', function(evt){
			recordingTimerService.start();
		});

		NB.addObserver('stopStopWatchFeedback', function(evt){
			recordingTimerService.stop(evt.eventData.recordedTime);
		});

		NB.addObserver('startPlaybackTimeFeedback', function(evt){
			playbackTimerService.start(evt.eventData.recordedTime);
		});

		NB.addObserver('pausePlaybackTimeFeedback', function(evt){
			playbackTimerService.pause();
		});

		NB.addObserver('resumePlaybackTimeFeedback', function(evt){
			playbackTimerService.resume();
		});

		NB.addObserver('prevPlaybackTimeFeedback', function(evt){
			playbackTimerService.prev();
		});

		NB.addObserver('nextPlaybackTimeFeedback', function(evt){
			playbackTimerService.next(evt.eventData.recordedTime);
			_scope.$digest();
		});

		NB.addObserver('resetPlaybackTimeFeedback', function(evt){
			playbackTimerService.prev();
			playbackTimerService.start();
			_scope.$digest();
		});

		NB.addObserver('toggleLoopFeedback', function(evt){
			widgetReceiveEventService.loopState = !widgetReceiveEventService.loopState; 
			_scope.$digest();
		});

		NB.addObserver('updateTotalRecordingTime', function(evt){
			recordingTimerService.setTotalDuration(evt.eventData.recordedTime);
			_scope.$digest();
		});

		return widgetReceiveEventService;
	}]);
});